.. _api-ref:

*************
API reference
*************

.. warning:: API stability

    Only APIs documented here are public and open for use by Mopidy
    extensions. We will change these APIs, but will keep the changelog up to
    date with all breaking changes.

    From Mopidy 1.0 and onwards, we intend to keep these APIs far more stable.


.. toctree::
    :glob:

    concepts
    models
    backends
    core
    audio
    frontends
    commands
    ext
    config
    zeroconf
    http
